Enum offchain::types::Status[][src]

pub enum Status {
    None,
    NeedsKycData,
    ReadyForSettlement,
    Abort,
    SoftMatch,
}

Variants

None

No status is yet set from this actor.

NeedsKycData

KYC data about the subaddresses is required by this actor.

ReadyForSettlement

Transaction is ready for settlement according to this actor (i.e. the requried signatures/KYC data has been provided.

Abort

Indicates the actor wishes to abort this payment, instaed of settling it.

SoftMatch

Actor’s KYC data resulted in a soft-match, request additional KYC data.