Struct offchain::types::PaymentActionObject[][src]

pub struct PaymentActionObject {
    pub amount: u64,
    pub currency: String,
    pub action: ActionType,
    pub timestamp: u64,
}

Fields

amount: u64

Amount of the transfer. Base units are the same as for on-chain transactions for this currency. For example, if DiemUSD is represented on-chain where “1” equals 1e-6 dollars, then “1” equals the same amount here. For any currency, the on-chain mapping must be used for amounts.

currency: String

One of the supported on-chain currency types - ex. XUS, etc.

action: ActionType

Populated in the request. This value indicates the requested action to perform, and the only valid value is charge.

timestamp: u64

Unix time indicating the time that the payment Command was created.