Struct offchain::types::PaymentActorObject[][src]

pub struct PaymentActorObject {
    pub address: Box<str>,
    pub kyc_data: Option<KycDataObject>,
    pub status: StatusObject,
    pub metadata: Vec<String>,
    pub additional_kyc_data: Option<String>,
}
A PaymentActorObject represents a participant in a payment - either sender or receiver. It also includes the status of the actor, indicates missing information or willingness to settle or abort the payment, and the Know-Your-Customer information of the customer involved in the payment.

Fields

address: Box<str>

Address of the sender/receiver account. Addresses may be single use or valid for a limited time, and therefore VASPs should not rely on them remaining stable across time or different VASP addresses. The addresses are encoded using bech32. The bech32 address encodes both the address of the VASP as well as the specific user’s subaddress. They should be no longer than 80 characters. Mandatory and immutable. For Diem addresses, refer to the “account identifier” section in DIP-5 for format.

kyc_data: Option<KycDataObject>

The KYC data for this account. This field is optional but immutable once it is set.

status: StatusObject

Status of the payment from the perspective of this actor. This field can only be set by the respective sender/receiver VASP and represents the status on the sender/receiver VASP side. This field is mandatory by this respective actor (either sender or receiver side) and mutable. Note that in the first request (which is initiated by the sender), the receiver status should be set to None.

metadata: Vec<String>

Can be specified by the respective VASP to hold metadata that the sender/receiver VASP wishes to associate with this payment. It may be set to an empty list (i.e. []). New metadata elements may be appended to the metadata list via subsequent commands on an object.

additional_kyc_data: Option<String>

Freeform KYC data. If a soft-match occurs, this field can be used to specify additional KYC data which can be used to clear the soft-match. It is suggested that this data be JSON, XML, or another human-readable form.

Implementations