Struct offchain::types::PaymentObject[][src]

pub struct PaymentObject {
    pub sender: PaymentActorObject,
    pub receiver: PaymentActorObject,
    pub reference_id: Uuid,
    pub originial_payment_reference_id: Option<Uuid>,
    pub recipient_signature: Option<String>,
    pub action: PaymentActionObject,
    pub description: Option<String>,
}
Some fields are immutable after they are defined once. Others can be updated multiple times (see below). Updating immutable fields with a different value results in a Command error.

Fields

sender: PaymentActorObject

Information about the sender in this payment

receiver: PaymentActorObject

Information about the receiver in this payment

reference_id: Uuid

Unique reference ID of this payment on the payment initiator VASP (the VASP which originally created this payment Object). This value should be globally unique. This field is mandatory on payment creation and immutable after that. We recommend using a 128 bits long UUID according to RFC4122 with “-”’s included.

originial_payment_reference_id: Option<Uuid>

Used to refer an old payment known to the other VASP. For example, used for refunds. The reference ID of the original payment will be placed into this field. This field is mandatory on refund and immutable

recipient_signature: Option<String>

Signature of the recipient of this transaction encoded in hex. The is signed with the compliance key of the recipient VASP and is used for on-chain attestation from the recipient party. This may be omitted on blockchains which do not require on-chain attestation.

action: PaymentActionObject

Number of cryptocurrency + currency type (XUS, etc.)1 + type of action to take. This field is mandatory and immutable

description: Option<String>

Description of the payment. To be displayed to the user. Unicode utf-8 encoded max length of 255 characters. This field is optional but can only be written once.

Implementations