Struct offchain::types::StatusObject [−][src]
pub struct StatusObject {
pub status: Status,
pub abort_code: Option<AbortCode>,
pub abort_message: Option<String>,
}Fields
status: StatusStatus of the payment from the perspective of this actor. This field can only be set by the respective sender/receiver VASP and represents the status on the sender/receiver VASP side. This field is mandatory by this respective actor (either sender or receiver side) and mutable.
abort_code: Option<AbortCode>In the case of an abort status, this field may be used to describe the reason for the
abort. Represents the error code of the corresponding error.
abort_message: Option<String>Additional details about this error. To be used only when abort_code is populated.
Implementations