Enum offchain::types::Status [−][src]
pub enum Status {
None,
NeedsKycData,
ReadyForSettlement,
Abort,
SoftMatch,
}Variants
No status is yet set from this actor.
KYC data about the subaddresses is required by this actor.
Transaction is ready for settlement according to this actor (i.e. the requried signatures/KYC data has been provided.
Indicates the actor wishes to abort this payment, instaed of settling it.
Actor’s KYC data resulted in a soft-match, request additional KYC data.