Struct offchain::types::KycDataObject [−][src]
pub struct KycDataObject {
pub kyc_data_type: KycDataObjectType,
pub given_name: Option<String>,
pub surname: Option<String>,
pub address: Option<AddressObject>,
pub dob: Option<String>,
pub place_of_birth: Option<String>,
pub national_id: Option<NationalIdObject>,
pub legal_entity_name: Option<String>,
// some fields omitted
}Expand description
A KycDataObject represents the required information for a single subaddress. Proof of
non-repudiation is provided by the signatures included in the JWS payloads. The only mandatory
fields are payload_version and type. All other fields are optional from the point of view of
the protocol – however they may need to be included for another VASP to be ready to settle the
payment.
Fields
kyc_data_type: KycDataObjectTypegiven_name: Option<String>Legal given name of the user for which this KYC data Object applies.
surname: Option<String>Legal surname of the user for which this KYC data Object applies.
address: Option<AddressObject>Physical address data for this account
dob: Option<String>Date of birth for the holder of this account. Specified as an ISO 8601 calendar date format: https://en.wikipedia.org/wiki/ISO_8601
place_of_birth: Option<String>Place of birth for this user. line1 and line2 fields should not be populated for this usage of the address Object
national_id: Option<NationalIdObject>National ID information for the holder of this account
legal_entity_name: Option<String>Name of the legal entity. Used when subaddress represents a legal entity rather than an individual. KYCDataObject should only include one of legal_entity_name OR given_name/surname
Implementations